# Welcome to davinciGPT

davinciGPT uses API from OpenAI and help you easily integrate it in your python project.

## Getting Started

To get started, first install the module using the following command in your terminal:

```pip install davinciGPT```

## Token

To get your own token to get access to chatbot, please visit [here](https://t.me/SOME1_HING/220)

## Example

```python
from davinciGPT import Chatbot

bot = Chatbot(<YOUR TOKEN>)
res = bot.chatbot("Hello")

print(res)
```

Output: ```Hi there! How can I help you?```
